/*
 *  xfmedia - simple gtk2 media player based on xine
 *
 *  Copyright (c) 2004-2005 Brian Tarricone, <bjt23@cornell.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License ONLY.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __XFMEDIA_XFMEDIA_KEYBINDINGS_H__
#define __XFMEDIA_XFMEDIA_KEYBINDINGS_H__

#include <gtk/gtkwidget.h>

#include "xfmedia-common.h"

G_BEGIN_DECLS

void xfmedia_keybindings_activate(XfmediaMainwin *mwin, const gchar *keybind_id);
GtkWidget *xfmedia_keybindings_create_editor(XfmediaMainwin *mwin, GtkWidget *parent);

G_END_DECLS

#endif
